==> haskell-th-compat-0.1.6-69-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-th-compat.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 th-compat
version:              0.1.6
visibility:           public
id:                   th-compat-0.1.6-85M4uPGOSLb1o35TF6AveO
key:                  th-compat-0.1.6-85M4uPGOSLb1o35TF6AveO
license:              BSD-3-Clause
copyright:            (C) 2020 Ryan Scott
maintainer:           Ryan Scott <ryan.gl.scott@gmail.com>
author:               Ryan Scott
homepage:             https://github.com/haskell-compat/th-compat
synopsis:             Backward- (and forward-)compatible Quote and Code types
description:
    This package defines a "Language.Haskell.TH.Syntax.Compat"
    module, which backports the @Quote@ and @Code@ types to
    work across a wide range of @template-haskell@ versions.
    The @makeRelativeToProject@ utility is also backported.
    On recent versions of @template-haskell@ (2.17.0.0 or
    later), this module simply reexports definitions
    from "Language.Haskell.TH.Syntax". Refer to the Haddocks
    for "Language.Haskell.TH.Syntax.Compat" for examples of
    how to use this module.

category:             Text
abi:                  c9ade9a3f3c57856ebf9e96c3bfd7ff8
exposed:              True
exposed-modules:      Language.Haskell.TH.Syntax.Compat
import-dirs:          /usr/lib/ghc-9.4.8/site-local/th-compat-0.1.6
library-dirs:         /usr/lib/ghc-9.4.8/site-local/th-compat-0.1.6
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/th-compat-0.1.6
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-th-compat
hs-libraries:         HSth-compat-0.1.6-85M4uPGOSLb1o35TF6AveO
depends:              base-4.17.2.1 template-haskell-2.19.0.0
haddock-interfaces:   /usr/share/doc/haskell-th-compat/html/th-compat.haddock
haddock-html:         /usr/share/doc/haskell-th-compat/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-th-compat-0.1.6-70-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-th-compat.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 th-compat
version:              0.1.6
visibility:           public
id:                   th-compat-0.1.6-3T4uoPly2m55QZYohviMel
key:                  th-compat-0.1.6-3T4uoPly2m55QZYohviMel
license:              BSD-3-Clause
copyright:            (C) 2020 Ryan Scott
maintainer:           Ryan Scott <ryan.gl.scott@gmail.com>
author:               Ryan Scott
homepage:             https://github.com/haskell-compat/th-compat
synopsis:             Backward- (and forward-)compatible Quote and Code types
description:
    This package defines a "Language.Haskell.TH.Syntax.Compat"
    module, which backports the @Quote@ and @Code@ types to
    work across a wide range of @template-haskell@ versions.
    The @makeRelativeToProject@ utility is also backported.
    On recent versions of @template-haskell@ (2.17.0.0 or
    later), this module simply reexports definitions
    from "Language.Haskell.TH.Syntax". Refer to the Haddocks
    for "Language.Haskell.TH.Syntax.Compat" for examples of
    how to use this module.

category:             Text
abi:                  ac11e111a6e9477b22600c217925f9da
exposed:              True
exposed-modules:      Language.Haskell.TH.Syntax.Compat
import-dirs:          /usr/lib/ghc-9.4.8/site-local/th-compat-0.1.6
library-dirs:         /usr/lib/ghc-9.4.8/site-local/th-compat-0.1.6
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/th-compat-0.1.6
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-th-compat
hs-libraries:         HSth-compat-0.1.6-3T4uoPly2m55QZYohviMel
depends:              base-4.17.2.1 template-haskell-2.19.0.0
haddock-interfaces:   /usr/share/doc/haskell-th-compat/html/th-compat.haddock
haddock-html:         /usr/share/doc/haskell-th-compat/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
